@@ -16,6 +16,8 @@
 
 import neptune
 
+from neptunecontrib.monitoring.utils import expect_not_a_run
+
 
 def neptune_monitor(experiment=None, prefix=''):
     """Logs lightGBM learning curves to Neptune.
@@ -78,6 +80,7 @@ def neptune_monitor(experiment=None, prefix=''):
     """
 
     _exp = experiment if experiment else neptune
+    expect_not_a_run(_exp)
 
     def callback(env):
         for name, loss_name, loss_value, _ in env.evaluation_result_list:
