@@ -18,6 +18,7 @@ import warnings
 import neptune
 
 from neptunecontrib.api import log_chart, pickle_and_log_artifact
+from neptunecontrib.monitoring.utils import expect_not_a_run
 
 
 class NeptuneCallback:
@@ -27,8 +28,17 @@ class NeptuneCallback:
 
     Args:
         experiment(`neptune.experiments.Experiment`): Neptune experiment. Default is None.
-        log_charts('bool'): Whether optuna visualization charts should be logged. By default no charts are logged.
         log_study('bool'): Whether optuna study object should be pickled and logged. By default it is not.
+        log_charts('bool'): Deprecated argument. Whether all optuna visualizations plots should be logged.
+            By default they are not.
+            To log all the charts set log_charts=True.
+            If you want to log a particular chart change the argument for that chart explicitly.
+            For example log_charts=False and log_slice=True will log only the slice plot to Neptune.
+        log_optimization_history('bool'): Whether optuna optimization history chart should be logged.
+           By default it is not.
+        log_contour('bool'): Whether optuna contour plot should be logged. By default it is not.
+        log_parallel_coordinate('bool'): Whether optuna parallel coordinate plot should be logged. By default it is not.
+        log_slice('bool'): Whether optuna slice chart should be logged. By default it is not.
         params(`list`): List of parameters to be visualized. Default is all parameters.
 
     Examples:
@@ -57,10 +67,35 @@ class NeptuneCallback:
             neptune_callback = opt_utils.NeptuneCallback(log_charts=True, log_study=True)
     """
 
-    def __init__(self, experiment=None, log_charts=False, log_study=False, params=None): # pylint: disable=W0621
+    def __init__(self, experiment=None,
+                 log_study=False,
+                 log_charts=False,
+                 log_optimization_history=False,
+                 log_contour=False,
+                 log_parallel_coordinate=False,
+                 log_slice=False,
+                 params=None):  # pylint: disable=W0621
         self.exp = experiment if experiment else neptune
-        self.log_charts = log_charts
         self.log_study = log_study
+
+        expect_not_a_run(self.exp)
+
+        if log_charts:
+
+            message = """log_charts argument is depraceted and will be removed in future releases.
+            Please use log_optimization_history, log_contour, log_parallel_coordinate, log_slice, arguments explicitly.
+            """
+            warnings.warn(message)
+
+            log_optimization_history = True
+            log_contour = True
+            log_parallel_coordinate = True
+            log_slice = True
+
+        self.log_optimization_history = log_optimization_history
+        self.log_contour = log_contour
+        self.log_parallel_coordinate = log_parallel_coordinate
+        self.log_slice = log_slice
         self.params = params
 
     def __call__(self, study, trial):
@@ -70,25 +105,28 @@ class NeptuneCallback:
         self.exp.log_metric('best_so_far_run_score', study.best_value)
         self.exp.log_text('run_parameters', str(trial.params))
 
-        if self.log_charts:
-            log_chart(name='optimization_history',
-                      chart=vis.plot_optimization_history(study),
-                      experiment=self.exp)
-            log_chart(name='contour',
-                      chart=vis.plot_contour(study, params=self.params),
-                      experiment=self.exp)
-            log_chart(name='parallel_coordinate',
-                      chart=vis.plot_parallel_coordinate(study, params=self.params),
-                      experiment=self.exp)
-            log_chart(name='slice',
-                      chart=vis.plot_slice(study, params=self.params),
-                      experiment=self.exp)
-
         if self.log_study:
             pickle_and_log_artifact(study, 'study.pkl', experiment=self.exp)
 
+        if self.log_optimization_history:
+            log_chart(name='optimization_history', chart=vis.plot_optimization_history(study), experiment=self.exp)
+        if self.log_contour:
+            log_chart(name='contour', chart=vis.plot_contour(study, params=self.params), experiment=self.exp)
+        if self.log_parallel_coordinate:
+            log_chart(name='parallel_coordinate', chart=vis.plot_parallel_coordinate(study, params=self.params),
+                      experiment=self.exp)
+        if self.log_slice:
+            log_chart(name='slice', chart=vis.plot_slice(study, params=self.params), experiment=self.exp)
 
-def log_study_info(study, experiment=None, log_charts=True, params=None):
+
+def log_study_info(study, experiment=None,
+                   log_study=True,
+                   log_charts=True,
+                   log_optimization_history=False,
+                   log_contour=False,
+                   log_parallel_coordinate=False,
+                   log_slice=False,
+                   params=None):
     """Logs runs results and parameters to neptune.
 
     Logs all hyperparameter optimization results to Neptune. Those include best score ('best_score' metric),
@@ -98,7 +136,16 @@ def log_study_info(study, experiment=None, log_charts=True, params=None):
     Args:
         study('optuna.study.Study'): Optuna study object after training is completed.
         experiment(`neptune.experiments.Experiment`): Neptune experiment. Default is None.
-        log_charts('bool'): Whether optuna visualization charts should be logged. By default all charts are logged.
+        log_study('bool'): Whether optuna study object should be logged as pickle. Default is True.
+        log_charts('bool'): Deprecated argument. Whether all optuna visualizations charts should be logged.
+            By default all charts are sent.
+            To not log any charts set log_charts=False.
+            If you want to log a particular chart change the argument for that chart explicitly.
+            For example log_charts=False and log_slice=True will log only the slice plot to Neptune.
+        log_optimization_history('bool'): Whether optuna optimization history chart should be logged. Default is True.
+        log_contour('bool'): Whether optuna contour plot should be logged. Default is True.
+        log_parallel_coordinate('bool'): Whether optuna parallel coordinate plot should be logged. Default is True.
+        log_slice('bool'): Whether optuna slice chart should be logged. Default is True.
         params(`list`): List of parameters to be visualized. Default is all parameters.
 
     Examples:
@@ -126,27 +173,29 @@ def log_study_info(study, experiment=None, log_charts=True, params=None):
 
     _exp = experiment if experiment else neptune
 
+    expect_not_a_run(_exp)
+
     _exp.log_metric('best_score', study.best_value)
     _exp.set_property('best_parameters', study.best_params)
 
     if log_charts:
+        message = """log_charts argument is depraceted and will be removed in future releases.
+        Please use log_optimization_history, log_contour, log_parallel_coordinate, log_slice, arguments explicitly.
+        """
+        warnings.warn(message)
+
+        log_optimization_history = True
+        log_contour = True
+        log_parallel_coordinate = True
+        log_slice = True
+
+    if log_study:
+        pickle_and_log_artifact(study, 'study.pkl', experiment=_exp)
+    if log_optimization_history:
         log_chart(name='optimization_history', chart=vis.plot_optimization_history(study), experiment=_exp)
+    if log_contour:
         log_chart(name='contour', chart=vis.plot_contour(study, params=params), experiment=_exp)
+    if log_parallel_coordinate:
         log_chart(name='parallel_coordinate', chart=vis.plot_parallel_coordinate(study, params=params), experiment=_exp)
+    if log_slice:
         log_chart(name='slice', chart=vis.plot_slice(study, params=params), experiment=_exp)
-
-    pickle_and_log_artifact(study, 'study.pkl', experiment=_exp)
-
-
-def log_study(study, experiment=None, log_charts=True, params=None):
-    message = """log_study was renamed to log_study_info and will be removed in future releases.
-    """
-    warnings.warn(message)
-    return log_study_info(study, experiment, log_charts, params)
-
-
-def NeptuneMonitor(experiment=None):
-    message = """NeptuneMonitor was renamed to NeptuneCallback and will be removed in future releases.
-    """
-    warnings.warn(message)
-    return NeptuneCallback(experiment=experiment)
